=======
pylobid
=======


.. image:: https://img.shields.io/pypi/v/pylobid.svg
        :target: https://pypi.python.org/pypi/pylobid

.. image:: https://img.shields.io/travis/csae8092/pylobid.svg
        :target: https://travis-ci.com/csae8092/pylobid

.. image:: https://readthedocs.org/projects/pylobid/badge/?version=latest
        :target: https://pylobid.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




`pylobid` is a  LOBID-REST-API client. Lobid_ is a web service providing data from the GND_ - Gemeinsame Normdatei of the German National Library.



* Free software: MIT license
* Documentation: https://pylobid.readthedocs.io.


Features
--------

* Harmonize GND-URIs and URLS
* wrap up several LOBID-API requests in a single methods

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Lobid: https://lobid.org/
.. _GND: https://www.dnb.de/DE/Professionell/Standardisierung/GND/gnd_node.html
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
